"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
const type_mapping_service_1 = require("./type-mapping.service");
class JsonMapper {
    constructor() {
        this.typeMapper = new type_mapping_service_1.TypeMappingService();
    }
    mapJson(sourceJson, mapping) {
        // loop through json and use map type
        // and map json to build the target
        const target = {};
        Object.keys(sourceJson)
            .forEach((key) => {
            const mapTo = mapping[key];
            /**
             * Can have keys in the source json that don't have an
             * explicit mapping, so ignore those...
             */
            if (mapTo) {
                let value = this.typeMapper.mapToType(sourceJson[key], mapTo.type);
                if (this._isNonBlank(value)) {
                    if (mapTo.isArray) {
                        let array = _.get(target, mapTo.path) || [];
                        array.push(value);
                        value = array;
                    }
                    _.set(target, mapTo.path, value);
                }
            }
        });
        return target;
    }
    _isNonBlank(value) {
        return value !== undefined && value !== null && value !== '';
    }
}
exports.JsonMapper = JsonMapper;
