"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const stream_1 = require("stream");
const json_mapper_1 = require("./json-mapper");
function createInstance(clazz, data = {}) {
    return new clazz(data);
}
class MappingStream extends stream_1.Transform {
    constructor(options) {
        super(options || {});
        this.mapping = options.mapping;
        this.clazz = options.clazz;
        this.jsonMapper = new json_mapper_1.JsonMapper();
        this.index = 0;
        if (!this.mapping) {
            throw new Error('No mapping supplied for mapping stream');
        }
        if (!this.clazz) {
            throw new Error('No clazz supplied for mapping streams');
        }
    }
    _transform(rawJson, encoding, next) {
        const mappedJson = this.jsonMapper.mapJson(rawJson, this.mapping);
        const mappedObject = createInstance(this.clazz, mappedJson);
        const prunedObject = this._pruneBlankValues(mappedObject);
        // TODO: Is valid?
        this.push(prunedObject);
        this.index++;
        if (this.index % 10000 === 0) {
            console.log('Items processed:', this.index);
        }
        next();
    }
    _pruneBlankValues(obj) {
        obj = JSON.stringify(obj, (key, value) => {
            if (value === undefined || value === null || value === '') {
                return undefined;
            }
            return value;
        });
        return JSON.parse(obj);
    }
}
exports.MappingStream = MappingStream;
